@@ -107,7 +107,7 @@ if python_prefix_matches and python_version_matches:
 
         print("888")
         # config.init(collector="127.0.0.1:8111", service="as you wish")
-        config.init(collector="only-fluent-bit:5140", service="as you wish")
+        config.init(collector="fluent-bit:5140", service="as you wish")
         print("999")
         agent.start()
         print("101010")
