@@ -85,20 +85,24 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         :param generator:
         :return:
         """
-        print("b1")
-        udp_sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)  # Internet  # UDP
-        print("b2")
-        for segment in generator:
-            print("b3")
-            for span in segment.spans:
-                print("b4")
-                data = self._get_data(segment, span)
-                print("b5")
-                res = udp_sock.sendto(data, ('only-fluent-bit', 5140))
-                print("b6")
-                print("res:", res)
-                # logger.debug("report traces response: %s", res)
-                print("sended message: %s" % data)
+        try:
+            print("b1")
+            udp_sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)  # Internet  # UDP
+            print("b2")
+            for segment in generator:
+                print("b3")
+                for span in segment.spans:
+                    print("b4")
+                    data = self._get_data(segment, span)
+                    print("b5")
+                    res = udp_sock.sendto(data, ('fluent-bit', 5140))
+                    print("b6")
+                    print("res:", res)
+                    # logger.debug("report traces response: %s", res)
+                    print("sended message: %s" % data)
+        except BaseException as e:
+            print("udp report error:", e)
+
 
     def _get_data(self, segment, span):
         """
